errorlit!() { /* proc-macro */ }Expand description
Produces a string literal at compile time in an error format.
Example:
#[cfg(some_broken_flag)]
core::compile_error!(errorlit!(
"The `some_broken_flag` is broken!",
"Please use turn it off"
));It is required that at least one string literal is passed into it. It will server as the quick error message. The rest of the passed literals will be additional information, for example a suggestion on how to fix the error.